@@ -160,7 +160,6 @@ class NumerousSystem:
                     self.update_inputs(data)
                     self.initialize_model()
                     self.nc.set_scenario_progress('model initialized', ScenarioStatus.INITIALZING, 0.0)
-                    self._initialized = True
                     break
 
                 except DataSourceStreamStarting:
@@ -169,9 +168,7 @@ class NumerousSystem:
                     continue
                 except Exception as e:
                     self.logger.error(f"could not initialize model {tb_str(e)}")
-                    break
-        else:
-            self._initialized = True
+                    raise
 
         self.logger.debug("completed setup")
 
@@ -330,6 +327,9 @@ class NumerousSystem:
 
         # Make a complete dict with formatted specifications
 
+        if self._model_folder == '.':
+            path = path.lstrip('.')
+
         component = Component(
                               component_id=component_id,
                               container_id=container_id,
